"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const react_1 = require("react");
const SequencePanel_1 = __importDefault(require("@jbrowse/core/BaseFeatureWidget/SequencePanel"));
const assembleBundle_1 = require("../assembleBundle");
const copy_to_clipboard_1 = __importDefault(require("copy-to-clipboard"));
const reactstrap_1 = require("reactstrap");
function GenericSeqPanel({ nclistbaseurl, fastaurl, refseq, mode, start, end, gene, transcript, urltemplate, }) {
    const [result, setResult] = (0, react_1.useState)();
    const [error, setError] = (0, react_1.useState)();
    const seqPanelRef = (0, react_1.useRef)(null);
    const [copied, setCopied] = (0, react_1.useState)(false);
    const [copiedHtml, setCopiedHtml] = (0, react_1.useState)(false);
    const [tooltipOpen, setTooltipOpen] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        (() => __awaiter(this, void 0, void 0, function* () {
            try {
                const res = yield (0, assembleBundle_1.assembleBundle)({
                    nclistbaseurl,
                    urltemplate,
                    fastaurl,
                    gene,
                    transcript,
                    refseq,
                });
                setResult(res);
                //	console.log(res.sequence.seq);
            }
            catch (e) {
                console.error(e);
                setError(e);
            }
        }))();
    }, [
        refseq,
        transcript,
        gene,
        start,
        end,
        fastaurl,
        urltemplate,
        nclistbaseurl,
    ]);
    if (error) {
        return (0, jsx_runtime_1.jsx)("div", Object.assign({ style: { color: "red" } }, { children: `${error}` }));
    }
    else if (!result) {
        return (0, jsx_runtime_1.jsx)("div", { children: "Loading..." });
    }
    else {
        return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(reactstrap_1.Button, Object.assign({ variant: "contained", style: { height: '34px' }, onClick: () => {
                        const ref = seqPanelRef.current;
                        if (ref) {
                            (0, copy_to_clipboard_1.default)(ref.textContent || '', { format: 'text/plain' });
                            setCopied(true);
                            setTimeout(() => setCopied(false), 1000);
                        }
                    } }, { children: copied ? 'Copied to clipboard!' : 'Copy plaintext' })), (0, jsx_runtime_1.jsx)(reactstrap_1.Button, Object.assign({ id: "CopyHighlightedButton", style: { height: '34px' }, variant: "contained", onClick: () => {
                        const ref = seqPanelRef.current;
                        if (!ref) {
                            return;
                        }
                        (0, copy_to_clipboard_1.default)(ref.innerHTML, { format: 'text/html' });
                        setCopiedHtml(true);
                        setTimeout(() => setCopiedHtml(false), 1000);
                    } }, { children: copiedHtml ? 'Copied to clipboard!' : 'Copy highlighted sequence' })), (0, jsx_runtime_1.jsx)(reactstrap_1.Tooltip, Object.assign({ target: "CopyHighlightedButton", isOpen: tooltipOpen, placement: "right", toggle: () => { setTooltipOpen(!tooltipOpen); } }, { children: (0, jsx_runtime_1.jsxs)("span", Object.assign({ style: { fontSize: "small" } }, { children: ["The \u2018Copy highlighted sequence\u2019 function retains the colors from the sequence panel", (0, jsx_runtime_1.jsx)("br", {}), " but cannot be pasted into some programs like notepad that only expect plain text."] })) })), (0, jsx_runtime_1.jsxs)("div", Object.assign({ style: { display: 'flex' } }, { children: [(0, jsx_runtime_1.jsx)("div", Object.assign({ className: "p-2" }, { children: (0, jsx_runtime_1.jsx)(SequencePanel_1.default, { ref: seqPanelRef, mode: mode, sequence: result.sequence, feature: result.feature }) })), (0, jsx_runtime_1.jsxs)("div", Object.assign({ className: "p-2" }, { children: [(0, jsx_runtime_1.jsx)("p", { children: "Legend:" }), (0, jsx_runtime_1.jsxs)("ul", { children: [(0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)("span", Object.assign({ style: { background: 'rgb(250, 200, 200)' } }, { children: "Up/downstream" })) }), (0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)("span", Object.assign({ style: { background: 'rgb(200, 240, 240)' } }, { children: "UTR" })) }), (0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)("span", Object.assign({ style: { background: 'rgb(220, 220, 180)' } }, { children: "Coding" })) }), (0, jsx_runtime_1.jsx)("li", { children: "Intron" }), (0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)("span", Object.assign({ style: { background: 'rgb(200, 255, 200)' } }, { children: "Genomic (i.e., unprocessed)" })) }), (0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)("span", Object.assign({ style: { background: 'rgb(220, 160, 220)' } }, { children: "Amino acid" })) })] }), (0, jsx_runtime_1.jsx)("p", Object.assign({ style: { fontSize: "small" } }, { children: "Note that lowercase bases generally indicate masked sequence." }))] }))] }))] }));
    }
}
exports.default = GenericSeqPanel;
