"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __asyncValues = (this && this.__asyncValues) || function (o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generic_filehandle_1 = require("generic-filehandle");
const nclist_1 = __importDefault(require("@gmod/nclist"));
// Create transcriptList function this function is called by the SeqPanel
// component when it needs to fetch a list of transcripts for a given gene it
// should return an array of transcript names (see @gmod/nclist for more info)
//
// it is called with five arguments:
// - nclistbaseurl: the base URL of the NCList file
// - urltemplate: the URL template for the NCList file
// - refseq: the reference sequence (name, like "chr1")
// - start: the start of the range (in interbase coordinates)
// - end: the end of the range (in interbase coordinates)
// - gene: the name of the gene
function fetchTranscripts({ nclistbaseurl, urltemplate, refseq, start, end, gene, }) {
    var _a, e_1, _b, _c;
    return __awaiter(this, void 0, void 0, function* () {
        const store = new nclist_1.default({
            urlTemplate: urltemplate,
            baseUrl: nclistbaseurl,
            readFile: (url) => new generic_filehandle_1.RemoteFile(url).readFile(),
        });
        try {
            for (var _d = true, _e = __asyncValues(store.getFeatures({
                refName: refseq,
                start: start,
                end: end,
            })), _f; _f = yield _e.next(), _a = _f.done, !_a;) {
                _c = _f.value;
                _d = false;
                try {
                    const feature = _c;
                    if (feature.get("name") === gene) {
                        return feature.get("subfeatures");
                    }
                }
                finally {
                    _d = true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (!_d && !_a && (_b = _e.return)) yield _b.call(_e);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return [];
    });
}
exports.default = fetchTranscripts;
