import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import { useState, useEffect, useRef } from "react";
import SequencePanel from "@jbrowse/core/BaseFeatureWidget/SequencePanel";
import { assembleBundle } from "../assembleBundle";
import copy from 'copy-to-clipboard';
import { Button, Tooltip } from 'reactstrap';
export default function GenericSeqPanel({ nclistbaseurl, fastaurl, refseq, mode, start, end, gene, transcript, urltemplate, }) {
    const [result, setResult] = useState();
    const [error, setError] = useState();
    const seqPanelRef = useRef(null);
    const [copied, setCopied] = useState(false);
    const [copiedHtml, setCopiedHtml] = useState(false);
    const [tooltipOpen, setTooltipOpen] = useState(false);
    useEffect(() => {
        (async () => {
            try {
                const res = await assembleBundle({
                    nclistbaseurl,
                    urltemplate,
                    fastaurl,
                    gene,
                    transcript,
                    refseq,
                });
                setResult(res);
                //	console.log(res.sequence.seq);
            }
            catch (e) {
                console.error(e);
                setError(e);
            }
        })();
    }, [
        refseq,
        transcript,
        gene,
        start,
        end,
        fastaurl,
        urltemplate,
        nclistbaseurl,
    ]);
    if (error) {
        return _jsx("div", { style: { color: "red" }, children: `${error}` });
    }
    else if (!result) {
        return _jsx("div", { children: "Loading..." });
    }
    else {
        return (_jsxs(_Fragment, { children: [_jsx(Button, { variant: "contained", style: { height: '34px' }, onClick: () => {
                        const ref = seqPanelRef.current;
                        if (ref) {
                            copy(ref.textContent || '', { format: 'text/plain' });
                            setCopied(true);
                            setTimeout(() => setCopied(false), 1000);
                        }
                    }, children: copied ? 'Copied to clipboard!' : 'Copy plaintext' }), _jsx(Button, { id: "CopyHighlightedButton", style: { height: '34px' }, variant: "contained", onClick: () => {
                        const ref = seqPanelRef.current;
                        if (!ref) {
                            return;
                        }
                        copy(ref.innerHTML, { format: 'text/html' });
                        setCopiedHtml(true);
                        setTimeout(() => setCopiedHtml(false), 1000);
                    }, children: copiedHtml ? 'Copied to clipboard!' : 'Copy highlighted sequence' }), _jsx(Tooltip, { target: "CopyHighlightedButton", isOpen: tooltipOpen, placement: "right", toggle: () => { setTooltipOpen(!tooltipOpen); }, children: _jsxs("span", { style: { fontSize: "small" }, children: ["The \u2018Copy highlighted sequence\u2019 function retains the colors from the sequence panel", _jsx("br", {}), " but cannot be pasted into some programs like notepad that only expect plain text."] }) }), _jsxs("div", { style: { display: 'flex' }, children: [_jsx("div", { className: "p-2", children: _jsx(SequencePanel, { ref: seqPanelRef, mode: mode, sequence: result.sequence, feature: result.feature }) }), _jsxs("div", { className: "p-2", children: [_jsx("p", { children: "Legend:" }), _jsxs("ul", { children: [_jsx("li", { children: _jsx("span", { style: { background: 'rgb(250, 200, 200)' }, children: "Up/downstream" }) }), _jsx("li", { children: _jsx("span", { style: { background: 'rgb(200, 240, 240)' }, children: "UTR" }) }), _jsx("li", { children: _jsx("span", { style: { background: 'rgb(220, 220, 180)' }, children: "Coding" }) }), _jsx("li", { children: "Intron" }), _jsx("li", { children: _jsx("span", { style: { background: 'rgb(200, 255, 200)' }, children: "Genomic (i.e., unprocessed)" }) }), _jsx("li", { children: _jsx("span", { style: { background: 'rgb(220, 160, 220)' }, children: "Amino acid" }) })] }), _jsx("p", { style: { fontSize: "small" }, children: "Note that lowercase bases generally indicate masked sequence." })] })] })] }));
    }
}
